# -*- coding: utf-8 -*-

try:
    import Image
    import ImageEnhance
except ImportError:
    from PIL import Image, ImageEnhance


def reduce_opacity(im, opacity):
    """Returns an image with reduced opacity."""
    assert 0 <= opacity <= 1
    im = im.convert('RGBA') if im.mode != 'RGBA' else im.copy()
    alpha = im.split()[3]
    alpha = ImageEnhance.Brightness(alpha).enhance(opacity)
    im.putalpha(alpha)
    return im


def watermark(im, mark, position, opacity=1, maxsize=(0, 0), possize=(0, 0, None, None)):
    """ Add watermark to image """
    if opacity < 1:
        mark = reduce_opacity(mark, opacity)
    # if im.mode != 'RGBA':
    #     im = im.convert('RGBA')
    # Resize mark
    w, h = int(min(mark.size[0], maxsize[0]) if maxsize[0] else mark.size[0]), int(min(mark.size[1], maxsize[1]) if maxsize[1] else mark.size[1])
    mark = mark.resize((w, h))
    # Create a transparent layer the size of the image
    # Draw the watermark in that layer.
    layer = Image.new('RGBA', im.size, (0, 0, 0, 0))
    if position == 'tile':
        for y in range(0, im.size[1], mark.size[1]):
            for x in range(0, im.size[0], mark.size[0]):
                layer.paste(mark, (x, y))
    elif position == 'scale':
        # Scale, but preserve the aspect ratio
        ratio = min(float(im.size[0]) / mark.size[0], float(im.size[1]) / mark.size[1])
        w, h = int(mark.size[0] * ratio), int(mark.size[1] * ratio)
        w, h = int(min(w, maxsize[0]) if maxsize[0] else w), int(min(h, maxsize[1]) if maxsize[1] else h)
        mark = mark.resize((w, h))
        possize += (None, ) * (4 - len(possize))
        lx, ly, rx, ry = possize
        if rx is None or ry is None:
            layer.paste(mark, ((im.size[0] - (lx or w)) / 2, (im.size[1] - (ly or h)) / 2))
        else:
            layer.paste(mark, ((im.size[0] - rx - w), ry))
    else:
        layer.paste(mark, position)
    # Composite the watermark with the layer
    return Image.composite(layer, im, layer)


def watermark_wrap(im_path, mark_path, save_path=''):
    im, mark = Image.open(im_path), Image.open(mark_path)
    # new_im = watermark(im, mark, (50, 50), 0.5)
    # new_im = watermark(im, mark, position='scale', opacity=1.0, maxsize=(400, 505.2), possize=(400, 400))
    new_im = watermark(im, mark, position='scale', opacity=1.0, maxsize=(200, 247.1875), possize=(0, 0, 15, 15))
    new_im.save(save_path or im_path)


def watermark_test():
    im, mark = Image.open('original_CGzC_10a50000c8811190.jpg'), Image.open('paiai_water_mark.png')
    watermark(im, mark, position='tile', opacity=0.5, maxsize=(40, 49.4375)).show()
    watermark(im, mark, position='scale', opacity=1.0, maxsize=(400, 494.375), possize=(400, 400)).show()
    watermark(im, mark, position='scale', opacity=1.0, maxsize=(200, 247.1875), possize=(0, 0, 10, 10)).show()
    watermark(im, mark, position=(50, 50), opacity=0.5, maxsize=(40, 49.4375)).show()


if __name__ == '__main__':
    # watermark_test()
    watermark_wrap('original_CGzC_10a50000c8811190.jpg', 'paiai_water_mark.png')
